==> mx-welcome_18.12.07.tar.xz: mx-welcome-18.12.07/translations/mx-welcome_is.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="is">
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>You must run this program as normal user.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>mxwelcome</name>
    <message>
        <location filename="../mxwelcome.ui" line="14"/>
        <location filename="../mxwelcome.cpp" line="54"/>
        <location filename="../mxwelcome.cpp" line="95"/>
        <location filename="../mxwelcome.cpp" line="107"/>
        <source>MX Welcome</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="51"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Welcome to MX Linux, a fast, friendly, and stable OS loaded with amazing tools and supported by a great community. &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="109"/>
        <source>Users Manual</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="160"/>
        <source>Forums</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="211"/>
        <source>Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="243"/>
        <source>Wiki</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="327"/>
        <source>Tools</source>
        <translation>Kerfistól</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="366"/>
        <source>Contribute</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="411"/>
        <source>Tweak (Panel, etc...)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="437"/>
        <source>Popular Apps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="460"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:14pt; font-weight:600;&quot;&gt;MX-17 &amp;quot;Horizon&amp;quot;&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="571"/>
        <source>Login Info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="591"/>
        <source>Show this dialog at start up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="649"/>
        <source>About this application</source>
        <translation>Um þetta forrit</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="652"/>
        <source>About...</source>
        <translation>Um hugbúnaðinn...</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="659"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="713"/>
        <source>Quit application</source>
        <translation>Hætta í forriti</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="716"/>
        <source>Close</source>
        <translation>Hætta</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="723"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="94"/>
        <source>About MX Welcome</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="95"/>
        <source>Version: </source>
        <translation>Útgáfa:</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="96"/>
        <source>Program for displaying a welcome screen in MX Linux</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="98"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Höfundarréttur (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="99"/>
        <source>License</source>
        <translation>Notkunarleyfi</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="100"/>
        <source>Changelog</source>
        <translation>Breytingaskrá</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="101"/>
        <source>Cancel</source>
        <translation>Hætta við</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="117"/>
        <source>&amp;Close</source>
        <translation>&amp;Loka</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="190"/>
        <source>Live Login Info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="191"/>
        <source>Default username:  &lt;b&gt;demo&lt;/b&gt; &lt;/p&gt; &lt;p align=&quot;center&quot;&gt;Default demo password:  &lt;b&gt;demo&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="192"/>
        <source>&lt;b&gt;Root&lt;/b&gt; Password:  &lt;b&gt;root&lt;/b&gt;&lt;/p&gt; </source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> mx-welcome_19.4.tar.xz: mx-welcome-19.4/translations/mx-welcome_is.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="is">
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>You must run this program as normal user.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>mxwelcome</name>
    <message>
        <location filename="../mxwelcome.ui" line="14"/>
        <location filename="../mxwelcome.cpp" line="54"/>
        <location filename="../mxwelcome.cpp" line="99"/>
        <location filename="../mxwelcome.cpp" line="111"/>
        <source>MX Welcome</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="70"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Welcome to MX Linux, a fast, friendly, and stable OS loaded with amazing tools and supported by a great community. &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="113"/>
        <source>Popular Apps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="203"/>
        <source>Forums</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="280"/>
        <source>Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="377"/>
        <source>Contribute</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="422"/>
        <source>Tweak (Panel, etc...)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="486"/>
        <source>Tools</source>
        <translation>Kerfistól</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="512"/>
        <source>Codecs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="544"/>
        <source>Wiki</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="576"/>
        <source>Users Manual</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="608"/>
        <source>FAQ</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="641"/>
        <source>Show this dialog at start up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="706"/>
        <source>About this application</source>
        <translation>Um þetta forrit</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="709"/>
        <source>About...</source>
        <translation>Um hugbúnaðinn...</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="716"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="770"/>
        <source>Quit application</source>
        <translation>Hætta í forriti</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="773"/>
        <source>Close</source>
        <translation>Hætta</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="780"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="57"/>
        <source>Default username:  &lt;b&gt;demo&lt;/b&gt; &lt;/p&gt; &lt;p align=&quot;center&quot;&gt;Default demo password:  &lt;b&gt;demo&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="58"/>
        <source>&lt;b&gt;Root&lt;/b&gt; Password:  &lt;b&gt;root&lt;/b&gt;&lt;/p&gt; </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="98"/>
        <source>About MX Welcome</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="99"/>
        <source>Version: </source>
        <translation>Útgáfa:</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="100"/>
        <source>Program for displaying a welcome screen in MX Linux</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="102"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Höfundarréttur (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="103"/>
        <source>License</source>
        <translation>Notkunarleyfi</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="104"/>
        <source>Changelog</source>
        <translation>Breytingaskrá</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="105"/>
        <source>Cancel</source>
        <translation>Hætta við</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="121"/>
        <source>&amp;Close</source>
        <translation>&amp;Loka</translation>
    </message>
</context>
</TS>
